@@ -77,7 +77,6 @@ static GtkWidget *session_command_dialog;
 void apply (void);
 static void help_cb (void);
 static void update_gui (void);
-static void dirty_cb (void);
 static void add_startup_cb (void);
 static void edit_startup_cb (void);
 static void delete_startup_cb (void);
@@ -181,20 +180,41 @@ spc_value_notify (GConfClient *client, guint id, GConfEntry *entry, gpointer tb)
 	}
 }
 
+static gboolean
+show_message_dialog ()
+{
+	GtkWidget *dlg;
+	gint response;
+
+	dlg = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_QUESTION, GTK_BUTTONS_OK_CANCEL,
+				      _("Some changes are not saved.\nIs it still OK to exit?"));
+	response = gtk_dialog_run (GTK_DIALOG (dlg));
+	gtk_widget_destroy (dlg);
+	if (response != GTK_RESPONSE_OK) 
+		return TRUE;
+	else
+		return FALSE;
+}
+
+static gboolean
+spc_delete (void)
+{
+	gint ret = FALSE;
+	if (state_dirty)
+		ret = show_message_dialog ();
+
+	if (ret == TRUE) 
+		return TRUE;
+	else {
+		gtk_main_quit ();
+		return FALSE;
+	}
+}
+
 static void
 spc_close (void)
 {
-	if (state_dirty) {
-		GtkWidget *dlg;
-		gint response;
-		dlg = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_QUESTION, GTK_BUTTONS_OK_CANCEL,
-					      _("Some changes are not saved.\nIs it still OK to exit?"));
-		response = gtk_dialog_run (GTK_DIALOG (dlg));
-		gtk_widget_destroy (dlg);
-		if (response == GTK_RESPONSE_CANCEL) return;
-	}
-
-	gtk_main_quit ();
+	spc_delete ();
 }
 
 static GtkWidget *
@@ -226,7 +246,7 @@ capplet_build (void)
   b = gtk_dialog_add_button (GTK_DIALOG (dlg), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
   gtk_dialog_set_default_response (GTK_DIALOG (dlg), GTK_RESPONSE_CLOSE);
   g_signal_connect (G_OBJECT (b), "clicked", spc_close, NULL);
-  g_signal_connect (dlg, "delete-event", spc_close, NULL);
+  g_signal_connect (dlg, "delete-event", G_CALLBACK(spc_delete), NULL);
 
   /* FIXME: Get rid of global capplet variable, or use only it, not both (Lauris) */
   capplet = dlg;
@@ -261,7 +281,7 @@ capplet_build (void)
   /* Logout prompt */
   a = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
   gtk_box_pack_start (GTK_BOX (util_vbox), a, FALSE, FALSE, 0);
-  logout_prompt_button = gtk_check_button_new_with_mnemonic (_("_Prompt on logout"));
+  logout_prompt_button = gtk_check_button_new_with_mnemonic (_("As_k on logout"));
   gtk_container_add (GTK_CONTAINER (a), logout_prompt_button);
   g_object_set_data (G_OBJECT (logout_prompt_button), "key", LOGOUT_PROMPT_KEY);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (logout_prompt_button),
@@ -359,7 +379,7 @@ capplet_build (void)
   startup_list = startup_list_read ("Default");
   startup_list_revert = startup_list_duplicate (startup_list);
 
-  vbox = session_properties_create_page (&dirty_cb);
+  vbox = session_properties_create_page (&mark_dirty);
 
   label = gtk_label_new (_("Current Session"));
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
@@ -401,20 +421,20 @@ capplet_build (void)
 
   /* Add/Edit/Delete buttons */
   button = left_aligned_stock_button (GTK_STOCK_ADD);
-  gtk_signal_connect (GTK_OBJECT (button), "clicked",
-		      GTK_SIGNAL_FUNC (add_startup_cb), NULL);
+  g_signal_connect (button, "clicked",
+		    G_CALLBACK (add_startup_cb), NULL);
   gtk_box_pack_start (GTK_BOX (util_vbox), button, FALSE, FALSE, 0);
   
   button = left_aligned_stock_button (SESSION_STOCK_EDIT);
-  gtk_signal_connect (GTK_OBJECT (button), "clicked",
-		      GTK_SIGNAL_FUNC (edit_startup_cb), NULL);
+  g_signal_connect (button, "clicked",
+		    G_CALLBACK (edit_startup_cb), NULL);
   gtk_box_pack_start (GTK_BOX (util_vbox), button, FALSE, FALSE, 0);
   gtk_widget_set_sensitive (button, FALSE);
   g_object_set_data (G_OBJECT (startup_view), "edit", button);
   
   button = left_aligned_stock_button (GTK_STOCK_DELETE);
-  gtk_signal_connect (GTK_OBJECT (button), "clicked",
-		      GTK_SIGNAL_FUNC (delete_startup_cb), NULL);
+  g_signal_connect (button, "clicked",
+		    G_CALLBACK (delete_startup_cb), NULL);
   gtk_box_pack_start (GTK_BOX (util_vbox), button, FALSE, FALSE, 0);
   gtk_widget_set_sensitive (button, FALSE);
   g_object_set_data (G_OBJECT (startup_view), "delete", button);
@@ -448,7 +468,7 @@ static void
 help_cb (void)
 {
   GError *error = NULL;
-  gnome_help_display_desktop (NULL, "user-guide", "wgoscustlookandfeel.xml",
+  gnome_help_display_desktop (NULL, "user-guide", "user-guide.xml",
                               "goscustsession-5", &error);
   if (error) {
     GtkWidget *dialog;
@@ -503,8 +523,8 @@ update_gui (void)
 }
 
 /* This is called when an change is made in the client list.  */
-static void
-dirty_cb (void)
+void
+mark_dirty (void)
 {
   state_dirty = TRUE;
   gtk_widget_set_sensitive (apply_button, TRUE);
@@ -518,7 +538,6 @@ add_startup_cb (void)
    * this point so our dialog doesn't die if the user switches
    * away to a different capplet
    */
-  dirty_cb ();
   startup_list_add_dialog (&startup_list, &startup_command_dialog, capplet);
   update_gui ();
 }
@@ -531,7 +550,6 @@ edit_startup_cb (void)
    * this point so our dialog doesn't die if the user switches
    * away to a different capplet
    */
-  dirty_cb ();
   startup_list_edit_dialog (&startup_list, startup_store, startup_sel, &startup_command_dialog, capplet);
   update_gui ();
 }
@@ -540,7 +558,7 @@ edit_startup_cb (void)
 static void
 delete_startup_cb (void)
 {
-  dirty_cb ();
+  mark_dirty ();
   startup_list_delete (&startup_list, startup_store, startup_sel);
   update_gui ();
 }
@@ -595,7 +613,6 @@ add_session_cb(void)
    * this point so our dialog doesn't die if the user switches
    * away to a different capplet
    */
-  dirty_cb ();
   session_list_add_dialog (&session_list, &session_command_dialog, capplet);
   update_gui ();
 }
@@ -610,7 +627,6 @@ edit_session_cb (void)
    * this point so our dialog doesn't die if the user switches
    * away to a different capplet
    */
-  dirty_cb ();
   if (!gtk_tree_selection_get_selected (sessions_sel, NULL, &iter)) return;
   gtk_tree_model_get (sessions_store, &iter, 0, &str, -1);
   session_list_edit_dialog (&session_list, str, &hashed_sessions, &session_command_dialog, capplet);
@@ -623,7 +639,7 @@ delete_session_cb (void)
 {
   GtkTreeIter iter;
   gchar *str;
-  dirty_cb ();
+  mark_dirty ();
   if (!gtk_tree_selection_get_selected (sessions_sel, NULL, &iter)) return;
   gtk_tree_model_get (sessions_store, &iter, 0, &str, -1);
   session_list_delete (&session_list, str, &session_command_dialog);
@@ -645,7 +661,7 @@ main (int argc, char *argv[])
 		      GNOME_PROGRAM_STANDARD_PROPERTIES,
 		      NULL);
 
-  gnome_window_icon_set_default_from_file (GNOME_ICONDIR "/gnome-session.png");
+  gtk_window_set_default_icon_name ("gnome-session");
 
   client = gconf_client_get_default ();
   gconf_client_add_dir (client, GSM_GCONF_CONFIG_PREFIX, GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
